@@ -791,9 +791,11 @@ class FortranGraph:
 
         for r in root:
             self.root.append(self.data.get_node(r))
-            self.max_nesting = max(self.max_nesting, int(r.meta.graph_maxdepth))
-            self.max_nodes = max(self.max_nodes, int(r.meta.graph_maxnodes))
-            self.warn = self.warn or (r.settings.warn)
+            if hasattr(r, "meta"):
+                self.max_nesting = max(self.max_nesting, int(r.meta.graph_maxdepth))
+                self.max_nodes = max(self.max_nodes, int(r.meta.graph_maxnodes))
+            if hasattr(r, "settings"):
+                self.warn = self.warn or (r.settings.warn)
 
         ident = ident or f"{root[0].get_dir()}~~{root[0].ident}"
         self.ident = f"{ident}~~{self.__class__.__name__}"
@@ -976,7 +978,7 @@ class FortranGraph:
             try:
                 link = f'<a href="{attribs["URL"]}">{attribs["label"]}</a></td>'
             except KeyError:
-                link = f'{attribs["label"]}</td>'
+                link = f"{attribs['label']}</td>"
 
             node = f'<td rowspan="2" class="node" bgcolor="{attribs["color"]}">{link}'
 
@@ -1022,7 +1024,7 @@ class FortranGraph:
         def rainbowcolour(depth, maxd):
             if not self.data.coloured_edges:
                 return "#000000"
-            (r, g, b) = colorsys.hsv_to_rgb(float(depth) / maxd, 1.0, 1.0)
+            r, g, b = colorsys.hsv_to_rgb(float(depth) / maxd, 1.0, 1.0)
             return f"#{int(255 * r):02X}{int(255 * g):02X}{int(255 * b):02X}"
 
         for i, node in enumerate(sorted(nodes)):
